@@ -309,8 +309,7 @@ def create_rtdh_standard_msg(pd):
         restrictions.append({'type': 'permitted-oversize-loads-prohibited'})
 
     lane_impacts = get_lane_impacts(pd.get("properties/laneImpacts"), pd.get("properties/direction"))
-    # if direction != recorded_direction and all_lanes_open(lane_impacts):
-    if direction != recorded_direction or not all_lanes_open(lane_impacts):
+    if direction != recorded_direction and all_lanes_open(lane_impacts):
         return {}
 
 
